require "csv2qti/version"
require 'csv'
require 'pp'
require 'canvas_cc'
require 'fileutils'

module Csv2qti

  class Csv2qtiError < StandardError
  end

  class QuestionParseError < Csv2qtiError
  end

  def self.process_dir(path='.')

  end

  def self.process_file(path)
    course = nil
    current_primary = nil
    current_enabling = nil

    CSV.foreach(path, skip_blanks: true) do |row|
      begin
      if $INPUT_LINE_NUMBER == 1
        raise Csv2qtiError, "Course title not in first cell" unless row[0]
        course = Course.new(row[0], path)
        next
      end

      if row[1] == 'Title'
        # new Primary outcome
        current_primary = nil
        current_enabling = nil
      elsif row[0]
        # new outcome row
        current_enabling = nil
        if current_primary
          # New enabling outcome
          current_enabling = current_primary.add_enabling_outcome(row)
          # there is usually a question there too
          current_enabling.add_question(row)
        else
          # New primary Outcome
          current_primary = course.add_primary_outcome(row)
        end
      elsif current_enabling
        current_enabling.add_question(row)
      elsif row[2] == "Enabling Learning Outcome"
        # Header row for the enabling outcomes
        # If the CSVs aren't consistent we may need to use this
      else
        puts "what is row #{$INPUT_LINE_NUMBER}?"
        puts row
      end
      rescue QuestionParseError => e
        puts "line #{$INPUT_LINE_NUMBER + 1}: Problem parsing question: #{$!.message} (just Skipping)"
      rescue Csv2qtiError => e
        puts "line #{$INPUT_LINE_NUMBER + 1}: Error: #{$!.message}"
        raise e
      rescue
        puts "line #{$INPUT_LINE_NUMBER + 1}: Unknown Error for this data:"
        puts row
        raise $!
      end
    end

    course
  end
end

require 'csv2qti/course'
require 'csv2qti/outcome'
require 'csv2qti/question'
