module Csv2qti
  class Outcome
    attr_reader :title, :number, :enabling_outcomes, :description, :license, :questions, :guid

    def initialize(row, parent_outcome=nil)
      @number = row[0]
      @title = row[1]
      @description = row[2]
      @guid = row[3]
      @license = row[5]
      @parent_outcome = parent_outcome
      @enabling_outcomes = []
      @questions = []
    end

    def add_enabling_outcome(row)
      @enabling_outcomes << Outcome.new(row, self)
      @enabling_outcomes.last
    end

    def add_question(row)
      @questions << Question.generate(row)
    end

    def is_primary_outcome?
      !! @parent_outcome
    end

    def generate_assessment
      assessment = CanvasCc::CanvasCC::Models::Assessment.new
      assessment.identifier = rand(10000).to_s
      assessment.items = []
      assessment.title = @title
      add_questions(assessment)

      @enabling_outcomes.each do |eo|
        g = CanvasCc::CanvasCC::Models::QuestionGroup.new
        g.title = eo.title
        g.identifier = rand(10000).to_s
        g.selection_number = 1
        g.points_per_item = 1
        eo.add_questions(g)
        assessment.items << g
      end

      assessment
    end

    def add_questions(group)
      @questions.each do |q|
        q.add_to_group(group)
      end
    end

    def to_s
      if is_primary_outcome?
        "#{number}: #{title} - #{description} - #{guid} - #{license} - #{questions.count} questions"
      else
        "#{number}: #{title} - #{description} - #{guid} - #{license} - #{enabling_outcomes.count} enabling outcomes"
      end
    end
  end
end