module Csv2qti
  class Question
    TYPE = 7
    STEM = 8
    CORRECT = 9
    DISTRACTOR_1 = 10
    DISTRACTOR_2 = 11
    LICENSE = 12

    def self.generate(row)
      type = row[TYPE] || ''
      case type.downcase
        when ''
          raise Csv2qti::QuestionParseError, "Thought this row would be a question but its not."
        when 'mc'
          MultipleChoice.new(row)
        when 'mmc'
          MultipleSelect.new(row)
        when 'category'
          raise Csv2qti::QuestionParseError, "unsupported question type: #{row[TYPE]}"
        when 'matching'
          Matching.new(row)
        when 'process'
          raise Csv2qti::QuestionParseError, "unsupported question type: #{row[TYPE]}"
        else
          raise Csv2qti::QuestionParseError, "unknown question type: #{row[TYPE]}"
      end
    end

    attr_reader :stem, :license

    def initialize(row)
      @stem = process_stem(row[STEM])
      @license = row[LICENSE]
    end

    # converts image references to html
    # images look like this in the original value:
    # (image: https://s3-us-west-2.amazonaws.com/textimgs/Biology/FormativeAssessment+/Bio_C3_LO2.png)
    def process_stem(val)
      val.gsub(/\(image: ([^\)]*)\)/, %{<img src="\\1" />})
    end

    def process_distractors(row)
      [row[DISTRACTOR_1], row[DISTRACTOR_2]]
    end

    def generate_cc_question
      nil
    end

    def add_to_assessment(assessment)
      if q = generate_cc_question
        assessment.items << q
      end
    end

    def add_to_group(assessment)
      if q = generate_cc_question
        assessment.questions << q
      end
    end

    def to_qti
      ''
    end

    def type
      "unknown"
    end

    def to_s
      type
    end

  end
end

require 'csv2qti/question_types/multiple_choice'
require 'csv2qti/question_types/multiple_select'
require 'csv2qti/question_types/matching'