module Csv2qti
  class Matching < Question

    attr_reader :distractors, :answers

    def initialize(row)
      super(row)
      @answers = process_answers(row[CORRECT])
    end

    # parse out the matching answers that look like this:
    # "A—Alpha Carbon\nB—Amino Group\nC—Carboxyl Group\nD—Hydrogen Atom\nE—R Group"
    # or
    # "A--Alpha Carbon\nB--Amino Group\nC--Carboxyl Group\nD--Hydrogen Atom\nE--R Group"
    def process_answers(val)
      if val =~ /--/
        val.split("\n").map{|m|m.split("--")}
      elsif val =~ /—/
        val.split("\n").map{|m|m.split("—")}
      else
         raise Csv2qti::QuestionParseError, "Matching question doesn't seem to be formatted correctly: #{val}"
      end
    end

    def type
      'MATCHING'
    end

    def generate_cc_question
      question = CanvasCc::CanvasCC::Models::Question.create('matching_question')
      question.identifier = rand(10000)
      question.material = stem
      #question.distractors = %w(distractor1 distractor2)
      question.matches = @answers.map {|a| make_answer(a)}

      question
    end

    def to_qti
      Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |node|
       CanvasCc::CanvasCC::MatchingQuestionWriter.write_question(node, generate_cc_question)
      end.doc.to_xml
    end

    private

    def make_answer(match)
      {:id => rand(10000).to_s,
       :question_text => match.first,
       :question_text_format => '1',
       :answer_text => match.last}
    end

  end
end