module Csv2qti
  class MultipleSelect < Question

    attr_reader :distractors, :answers

    def initialize(row)
      super(row)
      @distractors = process_distractors(row)
      @answers = process_answers(row[CORRECT])
    end

    # parse out the multiple answers that look like this:
    # "*Helper\n*chains\n*Lower energies"
    def process_answers(val)
      val.split("\n").map { |a| a.gsub(/\A\*/, '') }
    end

    def type
      'MULTIPLE_SELECT'
    end

    def generate_cc_question
      question = CanvasCc::CanvasCC::Models::Question.create('multiple_answers_question')
      question.material = stem
      question.identifier = rand(10000)
      question.answers = @answers.map { |a| make_answer(a, true) } + @distractors.map { |d| make_answer(d) }
      question
    end

    def to_qti
      Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |node|
        CanvasCc::CanvasCC::MultipleAnswersQuestionWriter.write_question(node, generate_cc_question)
      end.doc.to_xml
    end

    private

    def make_answer(text, correct=false)
      answer = CanvasCc::CanvasCC::Models::Answer.new
      answer.id = rand(10000)
      answer.fraction = correct ? 1.0 : 0.0
      answer.answer_text = text
      answer
    end

  end
end